@@ -14,6 +14,7 @@
 #include <wlr/types/wlr_export_dmabuf_v1.h>
 #include <wlr/types/wlr_gamma_control_v1.h>
 #include <wlr/types/wlr_idle.h>
+#include <wlr/types/wlr_idle_notify_v1.h>
 #include <wlr/types/wlr_input_inhibitor.h>
 #include <wlr/types/wlr_layer_shell_v1.h>
 #include <wlr/types/wlr_output_layout.h>
@@ -75,9 +76,13 @@ typedef struct _PhocDesktopPrivate {
   GSettings             *settings;
   GSettings             *interface_settings;
 
+  /* Protocols from wlroots */
+  struct wlr_idle_notifier_v1 *idle_notifier_v1;
+
   /* Protocols without upstreamable implementations */
   PhocPhoshPrivate      *phosh;
   PhocGtkShell          *gtk_shell;
+
   /* Protocols that should go upstream */
   PhocLayerShellEffects *layer_shell_effects;
   PhocDeviceState       *device_state;
@@ -726,7 +731,6 @@ phoc_desktop_constructed (GObject *object)
   self->server_decoration_manager = wlr_server_decoration_manager_create (server->wl_display);
   wlr_server_decoration_manager_set_default_mode (self->server_decoration_manager,
                                                   WLR_SERVER_DECORATION_MANAGER_MODE_CLIENT);
-  self->idle = wlr_idle_create (server->wl_display);
   self->primary_selection_device_manager =
     wlr_primary_selection_v1_device_manager_create (server->wl_display);
 
@@ -739,6 +743,8 @@ phoc_desktop_constructed (GObject *object)
   self->input_method = wlr_input_method_manager_v2_create (server->wl_display);
   self->text_input = wlr_text_input_manager_v3_create (server->wl_display);
 
+  self->idle = wlr_idle_create (server->wl_display);
+  priv->idle_notifier_v1 = wlr_idle_notifier_v1_create (server->wl_display);
   priv->idle_inhibit = phoc_idle_inhibit_create (self->idle);
 
   priv->gtk_shell = phoc_gtk_shell_create (self, server->wl_display);
@@ -1226,3 +1232,15 @@ phoc_desktop_get_phosh_private (PhocDesktop *self)
 
   return priv->phosh;
 }
+
+void
+phoc_desktop_notify_activity (PhocDesktop *self, PhocSeat *seat)
+{
+  PhocDesktopPrivate *priv;
+
+  g_assert (PHOC_IS_DESKTOP (self));
+  priv = phoc_desktop_get_instance_private (self);
+
+  wlr_idle_notify_activity (self->idle, seat->seat);
+  wlr_idle_notifier_v1_notify_activity (priv->idle_notifier_v1, seat->seat);
+}
