@@ -103,7 +103,6 @@ struct _PhocAlphaLayerSurface {
 struct _PhocLayerShellEffects {
   GObject             parent;
 
-  guint32             version;
   struct wl_global   *global;
   GSList             *resources;
   GSList             *drag_surfaces;
@@ -369,7 +368,7 @@ phoc_alpha_layer_surface_destroy (PhocAlphaLayerSurface *alpha_surface)
   if (alpha_surface == NULL)
     return;
 
-  g_debug ("Destroying alpa_layer_surface %p (res %p)", alpha_surface, alpha_surface->resource);
+  g_debug ("Destroying alpha_layer_surface %p (res %p)", alpha_surface, alpha_surface->resource);
   layer_shell_effects = PHOC_LAYER_SHELL_EFFECTS (alpha_surface->layer_shell_effects);
   g_assert (PHOC_IS_LAYER_SHELL_EFFECTS (layer_shell_effects));
 
@@ -423,16 +422,6 @@ alpha_layer_surface_handle_destroy (struct wl_listener *listener, void *data)
 }
 
 
-/*
- * TODO: Use wlr_layer_surface_v1_from_resource instead
- *  https://gitlab.freedesktop.org/wlroots/wlroots/-/merge_requests/3480
- */
-static struct wlr_layer_surface_v1*
-phoc_wlr_layer_surface_from_resource (struct wl_resource *resource)
-{
-  return wl_resource_get_user_data (resource);
-}
-
 static void
 draggable_layer_surface_handle_destroy (struct wl_listener *listener, void *data)
 {
@@ -530,7 +519,7 @@ handle_get_draggable_layer_surface (struct wl_client   *client,
 
   self = phoc_layer_shell_effects_from_resource (layer_shell_effects_resource);
   g_assert (PHOC_IS_LAYER_SHELL_EFFECTS (self));
-  wlr_layer_surface = phoc_wlr_layer_surface_from_resource (layer_surface_resource);
+  wlr_layer_surface = wlr_layer_surface_v1_from_resource (layer_surface_resource);
   wlr_surface = wlr_layer_surface->surface;
   g_assert (wlr_surface);
 
@@ -590,7 +579,7 @@ handle_get_alpha_layer_surface (struct wl_client   *client,
 
   self = phoc_layer_shell_effects_from_resource (layer_shell_effects_resource);
   g_assert (PHOC_IS_LAYER_SHELL_EFFECTS (self));
-  wlr_layer_surface = phoc_wlr_layer_surface_from_resource (layer_surface_resource);
+  wlr_layer_surface = wlr_layer_surface_v1_from_resource (layer_surface_resource);
   wlr_surface = wlr_layer_surface->surface;
   g_assert (wlr_surface);
 
@@ -669,7 +658,6 @@ layer_shell_effects_bind (struct wl_client *client, void *data, uint32_t version
                                   layer_shell_effects_handle_resource_destroy);
 
   self->resources = g_slist_prepend (self->resources, resource);
-  self->version = version;
   return;
 }
 
@@ -956,7 +944,7 @@ accept_drag (PhocDraggableLayerSurface *drag_surface,
   struct wlr_layer_surface_v1 *wlr_layer_surface = drag_surface->layer_surface->layer_surface;
   struct wlr_output *wlr_output = wlr_layer_surface->output;
   PhocOutput *output;
-  uint32_t *target;
+  int32_t *target;
   int32_t margin = 0;
 
   output = PHOC_OUTPUT (wlr_output->data);
@@ -1016,9 +1004,10 @@ phoc_draggable_layer_surface_drag_start (PhocDraggableLayerSurface *drag_surface
 {
   PhocServer *server = phoc_server_get_default ();
   struct wlr_layer_surface_v1 *wlr_layer_surface = drag_surface->layer_surface->layer_surface;
-  struct wlr_box *output_box = wlr_output_layout_get_box (server->desktop->layout, wlr_layer_surface->output);
-  double sx = lx - drag_surface->geo.x - output_box->x;
-  double sy = ly - drag_surface->geo.y - output_box->y;
+  struct wlr_box output_box;
+  wlr_output_layout_get_box (server->desktop->layout, wlr_layer_surface->output, &output_box);
+  double sx = lx - drag_surface->geo.x - output_box.x;
+  double sy = ly - drag_surface->geo.y - output_box.y;
   bool is_handle = false;
   int32_t start_margin;
 
